summaryrefslogtreecommitdiffstats
path: root/ui/aura
diff options
context:
space:
mode:
authoravi <avi@chromium.org>2015-12-24 00:04:09 -0800
committerCommit bot <commit-bot@chromium.org>2015-12-24 08:05:13 +0000
commit4ca29411cd3832ada52812593040d68ad6ca7ab2 (patch)
tree0f69abb9fecba469fd0d166ecf66783572455eba /ui/aura
parente3c627097cf69e4ff73e89be52c22c080eb37f4d (diff)
downloadchromium_src-4ca29411cd3832ada52812593040d68ad6ca7ab2.zip
chromium_src-4ca29411cd3832ada52812593040d68ad6ca7ab2.tar.gz
chromium_src-4ca29411cd3832ada52812593040d68ad6ca7ab2.tar.bz2
Switch to standard integer types in ui/aura/.
BUG=138542 TBR=sky@chromium.org Review URL: https://codereview.chromium.org/1544163002 Cr-Commit-Position: refs/heads/master@{#366812}
Diffstat (limited to 'ui/aura')
-rw-r--r--ui/aura/bench/bench_main.cc2
-rw-r--r--ui/aura/client/default_capture_client.h2
-rw-r--r--ui/aura/client/window_stacking_client.h1
-rw-r--r--ui/aura/demo/demo_main.cc2
-rw-r--r--ui/aura/env.h1
-rw-r--r--ui/aura/gestures/gesture_recognizer_unittest.cc7
-rw-r--r--ui/aura/input_state_lookup_win.h2
-rw-r--r--ui/aura/layout_manager.h1
-rw-r--r--ui/aura/remote_window_tree_host_win.cc99
-rw-r--r--ui/aura/remote_window_tree_host_win.h67
-rw-r--r--ui/aura/test/aura_test_base.h2
-rw-r--r--ui/aura/test/aura_test_helper.h2
-rw-r--r--ui/aura/test/aura_test_utils.cc1
-rw-r--r--ui/aura/test/env_test_helper.h1
-rw-r--r--ui/aura/test/event_generator_delegate_aura.cc1
-rw-r--r--ui/aura/test/event_generator_delegate_aura.h1
-rw-r--r--ui/aura/test/run_all_unittests.cc1
-rw-r--r--ui/aura/test/test_cursor_client.h2
-rw-r--r--ui/aura/test/test_focus_client.h2
-rw-r--r--ui/aura/test/test_screen.cc4
-rw-r--r--ui/aura/test/test_screen.h1
-rw-r--r--ui/aura/test/test_window_delegate.h1
-rw-r--r--ui/aura/test/test_window_tree_client.h2
-rw-r--r--ui/aura/test/test_windows.cc2
-rw-r--r--ui/aura/test/ui_controls_factory_aurawin.cc2
-rw-r--r--ui/aura/test/ui_controls_factory_aurax11.cc1
-rw-r--r--ui/aura/test/ui_controls_factory_ozone.cc1
-rw-r--r--ui/aura/test/window_event_dispatcher_test_api.h2
-rw-r--r--ui/aura/test/window_test_api.h2
-rw-r--r--ui/aura/window.cc22
-rw-r--r--ui/aura/window.h20
-rw-r--r--ui/aura/window_event_dispatcher.cc5
-rw-r--r--ui/aura/window_event_dispatcher.h8
-rw-r--r--ui/aura/window_event_dispatcher_unittest.cc4
-rw-r--r--ui/aura/window_observer.h2
-rw-r--r--ui/aura/window_property.h68
-rw-r--r--ui/aura/window_targeter_unittest.cc1
-rw-r--r--ui/aura/window_tracker.h2
-rw-r--r--ui/aura/window_tree_host.h1
-rw-r--r--ui/aura/window_tree_host_mac.h1
-rw-r--r--ui/aura/window_tree_host_platform.cc1
-rw-r--r--ui/aura/window_tree_host_platform.h1
-rw-r--r--ui/aura/window_tree_host_x11.cc3
-rw-r--r--ui/aura/window_tree_host_x11.h3
-rw-r--r--ui/aura/window_unittest.cc3
45 files changed, 207 insertions, 153 deletions
diff --git a/ui/aura/bench/bench_main.cc b/ui/aura/bench/bench_main.cc
index 573e23e..3d76fec 100644
--- a/ui/aura/bench/bench_main.cc
+++ b/ui/aura/bench/bench_main.cc
@@ -10,10 +10,12 @@
#include "base/bind.h"
#include "base/command_line.h"
#include "base/i18n/icu_util.h"
+#include "base/macros.h"
#include "base/memory/scoped_ptr.h"
#include "base/message_loop/message_loop.h"
#include "base/strings/string_split.h"
#include "base/time/time.h"
+#include "build/build_config.h"
#include "cc/output/context_provider.h"
#include "gpu/command_buffer/client/gles2_interface.h"
#include "third_party/khronos/GLES2/gl2.h"
diff --git a/ui/aura/client/default_capture_client.h b/ui/aura/client/default_capture_client.h
index c9369a9..05e1826 100644
--- a/ui/aura/client/default_capture_client.h
+++ b/ui/aura/client/default_capture_client.h
@@ -5,8 +5,8 @@
#ifndef UI_AURA_CLIENT_DEFAULT_CAPTURE_CLIENT_H_
#define UI_AURA_CLIENT_DEFAULT_CAPTURE_CLIENT_H_
-#include "base/basictypes.h"
#include "base/compiler_specific.h"
+#include "base/macros.h"
#include "ui/aura/aura_export.h"
#include "ui/aura/client/capture_client.h"
diff --git a/ui/aura/client/window_stacking_client.h b/ui/aura/client/window_stacking_client.h
index 8482603..f0b9b66 100644
--- a/ui/aura/client/window_stacking_client.h
+++ b/ui/aura/client/window_stacking_client.h
@@ -5,7 +5,6 @@
#ifndef UI_AURA_CLIENT_WINDOW_STACKING_CLIENT_H_
#define UI_AURA_CLIENT_WINDOW_STACKING_CLIENT_H_
-#include "base/basictypes.h"
#include "base/memory/scoped_ptr.h"
#include "ui/aura/aura_export.h"
#include "ui/aura/window.h"
diff --git a/ui/aura/demo/demo_main.cc b/ui/aura/demo/demo_main.cc
index b76dde2..f485a8c 100644
--- a/ui/aura/demo/demo_main.cc
+++ b/ui/aura/demo/demo_main.cc
@@ -5,10 +5,12 @@
#include "base/at_exit.h"
#include "base/command_line.h"
#include "base/i18n/icu_util.h"
+#include "base/macros.h"
#include "base/memory/scoped_ptr.h"
#include "base/message_loop/message_loop.h"
#include "base/power_monitor/power_monitor.h"
#include "base/power_monitor/power_monitor_device_source.h"
+#include "build/build_config.h"
#include "third_party/skia/include/core/SkXfermode.h"
#include "ui/aura/client/default_capture_client.h"
#include "ui/aura/client/window_tree_client.h"
diff --git a/ui/aura/env.h b/ui/aura/env.h
index 6fbcb17..e8cdb24 100644
--- a/ui/aura/env.h
+++ b/ui/aura/env.h
@@ -5,6 +5,7 @@
#ifndef UI_AURA_ENV_H_
#define UI_AURA_ENV_H_
+#include "base/macros.h"
#include "base/memory/scoped_ptr.h"
#include "base/observer_list.h"
#include "base/supports_user_data.h"
diff --git a/ui/aura/gestures/gesture_recognizer_unittest.cc b/ui/aura/gestures/gesture_recognizer_unittest.cc
index 508ec6e..820c914 100644
--- a/ui/aura/gestures/gesture_recognizer_unittest.cc
+++ b/ui/aura/gestures/gesture_recognizer_unittest.cc
@@ -2,9 +2,12 @@
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
+#include <stdint.h>
+
#include <list>
#include "base/command_line.h"
+#include "base/macros.h"
#include "base/run_loop.h"
#include "base/strings/string_number_conversions.h"
#include "base/timer/timer.h"
@@ -377,7 +380,7 @@ class QueueTouchEventDelegate : public GestureEventConsumeDelegate {
DCHECK(!sent_events_ids_.empty());
if (sent_events_ids_.empty())
return;
- uint32 sent_event_id = sent_events_ids_.front();
+ uint32_t sent_event_id = sent_events_ids_.front();
sent_events_ids_.pop_front();
dispatcher_->ProcessedTouchEvent(
sent_event_id, window_,
@@ -387,7 +390,7 @@ class QueueTouchEventDelegate : public GestureEventConsumeDelegate {
Window* window_;
WindowEventDispatcher* dispatcher_;
AckState synchronous_ack_for_next_event_;
- std::list<uint32> sent_events_ids_;
+ std::list<uint32_t> sent_events_ids_;
DISALLOW_COPY_AND_ASSIGN(QueueTouchEventDelegate);
};
diff --git a/ui/aura/input_state_lookup_win.h b/ui/aura/input_state_lookup_win.h
index 04741fd..418c7ca 100644
--- a/ui/aura/input_state_lookup_win.h
+++ b/ui/aura/input_state_lookup_win.h
@@ -5,8 +5,8 @@
#ifndef UI_AURA_INPUT_STATE_LOOKUP_WIN_H_
#define UI_AURA_INPUT_STATE_LOOKUP_WIN_H_
-#include "base/basictypes.h"
#include "base/compiler_specific.h"
+#include "base/macros.h"
#include "ui/aura/input_state_lookup.h"
namespace aura {
diff --git a/ui/aura/layout_manager.h b/ui/aura/layout_manager.h
index 2ae4606..31ba54c 100644
--- a/ui/aura/layout_manager.h
+++ b/ui/aura/layout_manager.h
@@ -5,7 +5,6 @@
#ifndef UI_AURA_LAYOUT_MANAGER_H_
#define UI_AURA_LAYOUT_MANAGER_H_
-#include "base/basictypes.h"
#include "ui/aura/aura_export.h"
namespace gfx {
diff --git a/ui/aura/remote_window_tree_host_win.cc b/ui/aura/remote_window_tree_host_win.cc
index 6c43c99..fa86674 100644
--- a/ui/aura/remote_window_tree_host_win.cc
+++ b/ui/aura/remote_window_tree_host_win.cc
@@ -5,6 +5,7 @@
#include "ui/aura/remote_window_tree_host_win.h"
#include <windows.h>
+#include <stddef.h>
#include <algorithm>
@@ -33,7 +34,9 @@ namespace {
const char* kWindowTreeHostWinKey = "__AURA_REMOTE_WINDOW_TREE_HOST_WIN__";
// Sets the keystate for the virtual key passed in to down or up.
-void SetKeyState(uint8* key_states, bool key_down, uint32 virtual_key_code) {
+void SetKeyState(uint8_t* key_states,
+ bool key_down,
+ uint32_t virtual_key_code) {
DCHECK(key_states);
if (key_down)
@@ -43,8 +46,8 @@ void SetKeyState(uint8* key_states, bool key_down, uint32 virtual_key_code) {
}
// Sets the keyboard states for the Shift/Control/Alt/Caps lock keys.
-void SetVirtualKeyStates(uint32 flags) {
- uint8 keyboard_state[256] = {0};
+void SetVirtualKeyStates(uint32_t flags) {
+ uint8_t keyboard_state[256] = {0};
::GetKeyboardState(keyboard_state);
SetKeyState(keyboard_state, !!(flags & ui::EF_SHIFT_DOWN), VK_SHIFT);
@@ -62,8 +65,8 @@ void SetVirtualKeyStates(uint32 flags) {
void FillCompositionText(
const base::string16& text,
- int32 selection_start,
- int32 selection_end,
+ int32_t selection_start,
+ int32_t selection_end,
const std::vector<metro_viewer::UnderlineInfo>& underlines,
ui::CompositionText* composition_text) {
composition_text->Clear();
@@ -183,8 +186,8 @@ void RemoteWindowTreeHostWin::HandleOpenURLOnDesktop(
host_->Send(new MetroViewerHostMsg_OpenURLOnDesktop(shortcut, url));
}
-void RemoteWindowTreeHostWin::HandleWindowSizeChanged(uint32 width,
- uint32 height) {
+void RemoteWindowTreeHostWin::HandleWindowSizeChanged(uint32_t width,
+ uint32_t height) {
SetBounds(gfx::Rect(0, 0, width, height));
}
@@ -241,7 +244,7 @@ void RemoteWindowTreeHostWin::SetCursorNative(gfx::NativeCursor native_cursor) {
if (!host_)
return;
host_->Send(
- new MetroViewerHostMsg_SetCursor(uint64(native_cursor.platform())));
+ new MetroViewerHostMsg_SetCursor(uint64_t(native_cursor.platform())));
}
void RemoteWindowTreeHostWin::MoveCursorToNative(const gfx::Point& location) {
@@ -280,7 +283,7 @@ void RemoteWindowTreeHostWin::CancelComposition() {
}
void RemoteWindowTreeHostWin::OnTextInputClientUpdated(
- const std::vector<int32>& input_scopes,
+ const std::vector<int32_t>& input_scopes,
const std::vector<gfx::Rect>& composition_character_bounds) {
if (!host_)
return;
@@ -298,13 +301,15 @@ void RemoteWindowTreeHostWin::OnTextInputClientUpdated(
input_scopes, character_bounds));
}
-gfx::Point PointFromNativeEvent(int32 x, int32 y) {
+gfx::Point PointFromNativeEvent(int32_t x, int32_t y) {
static float scale_factor = gfx::GetDPIScale();
gfx::Point result( x * scale_factor, y * scale_factor);
return result;
}
-void RemoteWindowTreeHostWin::OnMouseMoved(int32 x, int32 y, int32 flags) {
+void RemoteWindowTreeHostWin::OnMouseMoved(int32_t x,
+ int32_t y,
+ int32_t flags) {
if (ignore_mouse_moves_until_set_cursor_ack_)
return;
@@ -348,26 +353,26 @@ void RemoteWindowTreeHostWin::OnMouseButton(
}
}
-void RemoteWindowTreeHostWin::OnKeyDown(uint32 vkey,
- uint32 repeat_count,
- uint32 scan_code,
- uint32 flags) {
+void RemoteWindowTreeHostWin::OnKeyDown(uint32_t vkey,
+ uint32_t repeat_count,
+ uint32_t scan_code,
+ uint32_t flags) {
DispatchKeyboardMessage(ui::ET_KEY_PRESSED, vkey, repeat_count, scan_code,
flags, false);
}
-void RemoteWindowTreeHostWin::OnKeyUp(uint32 vkey,
- uint32 repeat_count,
- uint32 scan_code,
- uint32 flags) {
+void RemoteWindowTreeHostWin::OnKeyUp(uint32_t vkey,
+ uint32_t repeat_count,
+ uint32_t scan_code,
+ uint32_t flags) {
DispatchKeyboardMessage(ui::ET_KEY_RELEASED, vkey, repeat_count, scan_code,
flags, false);
}
-void RemoteWindowTreeHostWin::OnChar(uint32 key_code,
- uint32 repeat_count,
- uint32 scan_code,
- uint32 flags) {
+void RemoteWindowTreeHostWin::OnChar(uint32_t key_code,
+ uint32_t repeat_count,
+ uint32_t scan_code,
+ uint32_t flags) {
DispatchKeyboardMessage(ui::ET_KEY_PRESSED, key_code, repeat_count,
scan_code, flags, true);
}
@@ -388,10 +393,10 @@ void RemoteWindowTreeHostWin::OnEdgeGesture() {
SendEventToProcessor(&event);
}
-void RemoteWindowTreeHostWin::OnTouchDown(int32 x,
- int32 y,
- uint64 timestamp,
- uint32 pointer_id) {
+void RemoteWindowTreeHostWin::OnTouchDown(int32_t x,
+ int32_t y,
+ uint64_t timestamp,
+ uint32_t pointer_id) {
gfx::Point location = PointFromNativeEvent(x, y);
ui::TouchEvent event(ui::ET_TOUCH_PRESSED,
location,
@@ -400,10 +405,10 @@ void RemoteWindowTreeHostWin::OnTouchDown(int32 x,
SendEventToProcessor(&event);
}
-void RemoteWindowTreeHostWin::OnTouchUp(int32 x,
- int32 y,
- uint64 timestamp,
- uint32 pointer_id) {
+void RemoteWindowTreeHostWin::OnTouchUp(int32_t x,
+ int32_t y,
+ uint64_t timestamp,
+ uint32_t pointer_id) {
gfx::Point location = PointFromNativeEvent(x, y);
ui::TouchEvent event(ui::ET_TOUCH_RELEASED,
location,
@@ -412,10 +417,10 @@ void RemoteWindowTreeHostWin::OnTouchUp(int32 x,
SendEventToProcessor(&event);
}
-void RemoteWindowTreeHostWin::OnTouchMoved(int32 x,
- int32 y,
- uint64 timestamp,
- uint32 pointer_id) {
+void RemoteWindowTreeHostWin::OnTouchMoved(int32_t x,
+ int32_t y,
+ uint64_t timestamp,
+ uint32_t pointer_id) {
gfx::Point location = PointFromNativeEvent(x, y);
ui::TouchEvent event(ui::ET_TOUCH_MOVED,
location,
@@ -444,8 +449,8 @@ void RemoteWindowTreeHostWin::OnImeCandidatePopupChanged(bool visible) {
void RemoteWindowTreeHostWin::OnImeCompositionChanged(
const base::string16& text,
- int32 selection_start,
- int32 selection_end,
+ int32_t selection_start,
+ int32_t selection_end,
const std::vector<metro_viewer::UnderlineInfo>& underlines) {
ui::RemoteInputMethodPrivateWin* remote_input_method_private =
GetRemoteInputMethodPrivate();
@@ -465,7 +470,7 @@ void RemoteWindowTreeHostWin::OnImeTextCommitted(const base::string16& text) {
remote_input_method_private->OnTextCommitted(text);
}
-void RemoteWindowTreeHostWin::OnImeInputSourceChanged(uint16 language_id,
+void RemoteWindowTreeHostWin::OnImeInputSourceChanged(uint16_t language_id,
bool is_ime) {
ui::RemoteInputMethodPrivateWin* remote_input_method_private =
GetRemoteInputMethodPrivate();
@@ -475,10 +480,10 @@ void RemoteWindowTreeHostWin::OnImeInputSourceChanged(uint16 language_id,
}
void RemoteWindowTreeHostWin::DispatchKeyboardMessage(ui::EventType type,
- uint32 vkey,
- uint32 repeat_count,
- uint32 scan_code,
- uint32 flags,
+ uint32_t vkey,
+ uint32_t repeat_count,
+ uint32_t scan_code,
+ uint32_t flags,
bool is_character) {
SetEventFlags(flags | mouse_event_flags());
if (base::MessageLoop::current()->IsNested()) {
@@ -486,10 +491,10 @@ void RemoteWindowTreeHostWin::DispatchKeyboardMessage(ui::EventType type,
const int char_message[] = {WM_CHAR, WM_SYSCHAR};
const int keydown_message[] = {WM_KEYDOWN, WM_SYSKEYDOWN};
const int keyup_message[] = {WM_KEYUP, WM_SYSKEYUP};
- uint32 message = is_character
- ? char_message[index]
- : (type == ui::ET_KEY_PRESSED ? keydown_message[index]
- : keyup_message[index]);
+ uint32_t message =
+ is_character ? char_message[index]
+ : (type == ui::ET_KEY_PRESSED ? keydown_message[index]
+ : keyup_message[index]);
::PostThreadMessage(::GetCurrentThreadId(),
message,
vkey,
@@ -507,7 +512,7 @@ void RemoteWindowTreeHostWin::DispatchKeyboardMessage(ui::EventType type,
}
}
-void RemoteWindowTreeHostWin::SetEventFlags(uint32 flags) {
+void RemoteWindowTreeHostWin::SetEventFlags(uint32_t flags) {
if (flags == event_flags_)
return;
event_flags_ = flags;
diff --git a/ui/aura/remote_window_tree_host_win.h b/ui/aura/remote_window_tree_host_win.h
index 340d75f..f0ff362 100644
--- a/ui/aura/remote_window_tree_host_win.h
+++ b/ui/aura/remote_window_tree_host_win.h
@@ -5,9 +5,12 @@
#ifndef UI_AURA_REMOTE_WINDOW_TREE_HOST_WIN_H_
#define UI_AURA_REMOTE_WINDOW_TREE_HOST_WIN_H_
+#include <stdint.h>
+
#include <vector>
#include "base/compiler_specific.h"
+#include "base/macros.h"
#include "base/strings/string16.h"
#include "ui/aura/window_tree_host.h"
#include "ui/base/ime/remote_input_method_delegate_win.h"
@@ -67,7 +70,7 @@ class AURA_EXPORT RemoteWindowTreeHostWin
void HandleOpenURLOnDesktop(const base::FilePath& shortcut,
const base::string16& url);
- void HandleWindowSizeChanged(uint32 width, uint32 height);
+ void HandleWindowSizeChanged(uint32_t width, uint32_t height);
// Returns the active ASH root window.
Window* GetAshWindow();
@@ -82,25 +85,31 @@ class AURA_EXPORT RemoteWindowTreeHostWin
private:
// IPC message handing methods:
- void OnMouseMoved(int32 x, int32 y, int32 flags);
+ void OnMouseMoved(int32_t x, int32_t y, int32_t flags);
void OnMouseButton(const MetroViewerHostMsg_MouseButtonParams& params);
- void OnKeyDown(uint32 vkey,
- uint32 repeat_count,
- uint32 scan_code,
- uint32 flags);
- void OnKeyUp(uint32 vkey,
- uint32 repeat_count,
- uint32 scan_code,
- uint32 flags);
- void OnChar(uint32 key_code,
- uint32 repeat_count,
- uint32 scan_code,
- uint32 flags);
+ void OnKeyDown(uint32_t vkey,
+ uint32_t repeat_count,
+ uint32_t scan_code,
+ uint32_t flags);
+ void OnKeyUp(uint32_t vkey,
+ uint32_t repeat_count,
+ uint32_t scan_code,
+ uint32_t flags);
+ void OnChar(uint32_t key_code,
+ uint32_t repeat_count,
+ uint32_t scan_code,
+ uint32_t flags);
void OnWindowActivated(bool repaint);
void OnEdgeGesture();
- void OnTouchDown(int32 x, int32 y, uint64 timestamp, uint32 pointer_id);
- void OnTouchUp(int32 x, int32 y, uint64 timestamp, uint32 pointer_id);
- void OnTouchMoved(int32 x, int32 y, uint64 timestamp, uint32 pointer_id);
+ void OnTouchDown(int32_t x,
+ int32_t y,
+ uint64_t timestamp,
+ uint32_t pointer_id);
+ void OnTouchUp(int32_t x, int32_t y, uint64_t timestamp, uint32_t pointer_id);
+ void OnTouchMoved(int32_t x,
+ int32_t y,
+ uint64_t timestamp,
+ uint32_t pointer_id);
void OnSetCursorPosAck();
// For Input Method support:
@@ -108,11 +117,11 @@ class AURA_EXPORT RemoteWindowTreeHostWin
void OnImeCandidatePopupChanged(bool visible);
void OnImeCompositionChanged(
const base::string16& text,
- int32 selection_start,
- int32 selection_end,
+ int32_t selection_start,
+ int32_t selection_end,
const std::vector<metro_viewer::UnderlineInfo>& underlines);
void OnImeTextCommitted(const base::string16& text);
- void OnImeInputSourceChanged(uint16 language_id, bool is_ime);
+ void OnImeInputSourceChanged(uint16_t language_id, bool is_ime);
// WindowTreeHost overrides:
ui::EventSource* GetEventSource() override;
@@ -131,7 +140,7 @@ class AURA_EXPORT RemoteWindowTreeHostWin
// ui::internal::RemoteInputMethodDelegateWin overrides:
void CancelComposition() override;
void OnTextInputClientUpdated(
- const std::vector<int32>& input_scopes,
+ const std::vector<int32_t>& input_scopes,
const std::vector<gfx::Rect>& composition_character_bounds) override;
// Helper function to dispatch a keyboard message to the desired target.
@@ -140,24 +149,24 @@ class AURA_EXPORT RemoteWindowTreeHostWin
// loop. The dispatcher for the nested loop would then decide how this
// message is routed.
void DispatchKeyboardMessage(ui::EventType type,
- uint32 vkey,
- uint32 repeat_count,
- uint32 scan_code,
- uint32 flags,
+ uint32_t vkey,
+ uint32_t repeat_count,
+ uint32_t scan_code,
+ uint32_t flags,
bool is_character);
// Sets the event flags. |flags| is a bitmask of EventFlags. If there is a
// change the system virtual key state is updated as well. This way if chrome
// queries for key state it matches that of event being dispatched.
- void SetEventFlags(uint32 flags);
+ void SetEventFlags(uint32_t flags);
- uint32 mouse_event_flags() const {
+ uint32_t mouse_event_flags() const {
return event_flags_ & (ui::EF_LEFT_MOUSE_BUTTON |
ui::EF_MIDDLE_MOUSE_BUTTON |
ui::EF_RIGHT_MOUSE_BUTTON);
}
- uint32 key_event_flags() const {
+ uint32_t key_event_flags() const {
return event_flags_ & (ui::EF_SHIFT_DOWN | ui::EF_CONTROL_DOWN |
ui::EF_ALT_DOWN | ui::EF_CAPS_LOCK_DOWN);
}
@@ -175,7 +184,7 @@ class AURA_EXPORT RemoteWindowTreeHostWin
// State of the keyboard/mouse at the time of the last input event. See
// description of SetEventFlags().
- uint32 event_flags_;
+ uint32_t event_flags_;
// Current size of this root window.
gfx::Size window_size_;
diff --git a/ui/aura/test/aura_test_base.h b/ui/aura/test/aura_test_base.h
index af89fc8..9d7644c 100644
--- a/ui/aura/test/aura_test_base.h
+++ b/ui/aura/test/aura_test_base.h
@@ -5,8 +5,8 @@
#ifndef UI_AURA_TEST_AURA_TEST_BASE_H_
#define UI_AURA_TEST_AURA_TEST_BASE_H_
-#include "base/basictypes.h"
#include "base/compiler_specific.h"
+#include "base/macros.h"
#include "base/message_loop/message_loop.h"
#include "testing/gtest/include/gtest/gtest.h"
#include "ui/aura/test/aura_test_helper.h"
diff --git a/ui/aura/test/aura_test_helper.h b/ui/aura/test/aura_test_helper.h
index 0cdaf3e..8fcf362 100644
--- a/ui/aura/test/aura_test_helper.h
+++ b/ui/aura/test/aura_test_helper.h
@@ -5,7 +5,7 @@
#ifndef UI_AURA_TEST_AURA_TEST_HELPER_H_
#define UI_AURA_TEST_AURA_TEST_HELPER_H_
-#include "base/basictypes.h"
+#include "base/macros.h"
#include "base/memory/scoped_ptr.h"
#include "ui/aura/window_event_dispatcher.h"
#include "ui/aura/window_tree_host.h"
diff --git a/ui/aura/test/aura_test_utils.cc b/ui/aura/test/aura_test_utils.cc
index 7a11b19..7a31136 100644
--- a/ui/aura/test/aura_test_utils.cc
+++ b/ui/aura/test/aura_test_utils.cc
@@ -6,6 +6,7 @@
#include <utility>
+#include "base/macros.h"
#include "ui/aura/window_event_dispatcher.h"
#include "ui/aura/window_tree_host.h"
diff --git a/ui/aura/test/env_test_helper.h b/ui/aura/test/env_test_helper.h
index fb64d46..4807f52 100644
--- a/ui/aura/test/env_test_helper.h
+++ b/ui/aura/test/env_test_helper.h
@@ -7,6 +7,7 @@
#include <utility>
+#include "base/macros.h"
#include "ui/aura/env.h"
#include "ui/aura/input_state_lookup.h"
diff --git a/ui/aura/test/event_generator_delegate_aura.cc b/ui/aura/test/event_generator_delegate_aura.cc
index 9ee54cf..30eb261 100644
--- a/ui/aura/test/event_generator_delegate_aura.cc
+++ b/ui/aura/test/event_generator_delegate_aura.cc
@@ -4,6 +4,7 @@
#include "ui/aura/test/event_generator_delegate_aura.h"
+#include "base/macros.h"
#include "base/memory/singleton.h"
#include "ui/aura/client/screen_position_client.h"
#include "ui/aura/window_event_dispatcher.h"
diff --git a/ui/aura/test/event_generator_delegate_aura.h b/ui/aura/test/event_generator_delegate_aura.h
index e235622..9ba58e1 100644
--- a/ui/aura/test/event_generator_delegate_aura.h
+++ b/ui/aura/test/event_generator_delegate_aura.h
@@ -5,6 +5,7 @@
#ifndef UI_AURA_TEST_EVENT_GENERATOR_DELEGATE_AURA_H_
#define UI_AURA_TEST_EVENT_GENERATOR_DELEGATE_AURA_H_
+#include "base/macros.h"
#include "ui/events/test/event_generator.h"
namespace aura {
diff --git a/ui/aura/test/run_all_unittests.cc b/ui/aura/test/run_all_unittests.cc
index 345cc28..0e7ff20 100644
--- a/ui/aura/test/run_all_unittests.cc
+++ b/ui/aura/test/run_all_unittests.cc
@@ -3,6 +3,7 @@
// found in the LICENSE file.
#include "base/bind.h"
+#include "base/macros.h"
#include "base/test/launcher/unit_test_launcher.h"
#include "base/test/test_suite.h"
#include "ui/aura/env.h"
diff --git a/ui/aura/test/test_cursor_client.h b/ui/aura/test/test_cursor_client.h
index c5412d2..8d3faaa 100644
--- a/ui/aura/test/test_cursor_client.h
+++ b/ui/aura/test/test_cursor_client.h
@@ -5,8 +5,8 @@
#ifndef UI_AURA_TEST_TEST_CURSOR_CLIENT_H_
#define UI_AURA_TEST_TEST_CURSOR_CLIENT_H_
-#include "base/basictypes.h"
#include "base/compiler_specific.h"
+#include "base/macros.h"
#include "base/observer_list.h"
#include "ui/aura/client/cursor_client.h"
diff --git a/ui/aura/test/test_focus_client.h b/ui/aura/test/test_focus_client.h
index 1863dfd..3945593 100644
--- a/ui/aura/test/test_focus_client.h
+++ b/ui/aura/test/test_focus_client.h
@@ -5,8 +5,8 @@
#ifndef UI_AURA_TEST_TEST_FOCUS_CLIENT_H_
#define UI_AURA_TEST_TEST_FOCUS_CLIENT_H_
-#include "base/basictypes.h"
#include "base/compiler_specific.h"
+#include "base/macros.h"
#include "base/scoped_observer.h"
#include "ui/aura/client/focus_client.h"
#include "ui/aura/window_observer.h"
diff --git a/ui/aura/test/test_screen.cc b/ui/aura/test/test_screen.cc
index bdf7b53..8a79157 100644
--- a/ui/aura/test/test_screen.cc
+++ b/ui/aura/test/test_screen.cc
@@ -4,6 +4,8 @@
#include "ui/aura/test/test_screen.h"
+#include <stdint.h>
+
#include "base/logging.h"
#include "ui/aura/env.h"
#include "ui/aura/window.h"
@@ -168,7 +170,7 @@ void TestScreen::RemoveObserver(gfx::DisplayObserver* observer) {
TestScreen::TestScreen(const gfx::Rect& screen_bounds)
: host_(NULL),
ui_scale_(1.0f) {
- static int64 synthesized_display_id = 2000;
+ static int64_t synthesized_display_id = 2000;
display_.set_id(synthesized_display_id++);
display_.SetScaleAndBounds(1.0f, screen_bounds);
}
diff --git a/ui/aura/test/test_screen.h b/ui/aura/test/test_screen.h
index dd3662a..03cb410 100644
--- a/ui/aura/test/test_screen.h
+++ b/ui/aura/test/test_screen.h
@@ -6,6 +6,7 @@
#define UI_AURA_TEST_TEST_SCREEN_H_
#include "base/compiler_specific.h"
+#include "base/macros.h"
#include "ui/aura/window_observer.h"
#include "ui/gfx/display.h"
#include "ui/gfx/screen.h"
diff --git a/ui/aura/test/test_window_delegate.h b/ui/aura/test/test_window_delegate.h
index 5ee001d..f816d7f 100644
--- a/ui/aura/test/test_window_delegate.h
+++ b/ui/aura/test/test_window_delegate.h
@@ -8,6 +8,7 @@
#include <string>
#include "base/compiler_specific.h"
+#include "base/macros.h"
#include "third_party/skia/include/core/SkColor.h"
#include "ui/aura/window_delegate.h"
#include "ui/events/keycodes/keyboard_codes.h"
diff --git a/ui/aura/test/test_window_tree_client.h b/ui/aura/test/test_window_tree_client.h
index d984f75..a21ae5c 100644
--- a/ui/aura/test/test_window_tree_client.h
+++ b/ui/aura/test/test_window_tree_client.h
@@ -5,8 +5,8 @@
#ifndef UI_AURA_TEST_TEST_WINDOW_TREE_CLIENT_H_
#define UI_AURA_TEST_TEST_WINDOW_TREE_CLIENT_H_
-#include "base/basictypes.h"
#include "base/compiler_specific.h"
+#include "base/macros.h"
#include "ui/aura/aura_export.h"
#include "ui/aura/client/window_tree_client.h"
diff --git a/ui/aura/test/test_windows.cc b/ui/aura/test/test_windows.cc
index 141510a..83b6aca 100644
--- a/ui/aura/test/test_windows.cc
+++ b/ui/aura/test/test_windows.cc
@@ -4,6 +4,8 @@
#include "ui/aura/test/test_windows.h"
+#include <stddef.h>
+
#include "base/strings/string_number_conversions.h"
#include "ui/aura/client/aura_constants.h"
#include "ui/aura/window.h"
diff --git a/ui/aura/test/ui_controls_factory_aurawin.cc b/ui/aura/test/ui_controls_factory_aurawin.cc
index 36953eb..43e2b7e 100644
--- a/ui/aura/test/ui_controls_factory_aurawin.cc
+++ b/ui/aura/test/ui_controls_factory_aurawin.cc
@@ -2,8 +2,8 @@
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
-#include "base/basictypes.h"
#include "base/logging.h"
+#include "base/macros.h"
#include "base/message_loop/message_loop.h"
#include "ui/aura/test/ui_controls_factory_aura.h"
#include "ui/aura/window.h"
diff --git a/ui/aura/test/ui_controls_factory_aurax11.cc b/ui/aura/test/ui_controls_factory_aurax11.cc
index 8999aa6..78f740e 100644
--- a/ui/aura/test/ui_controls_factory_aurax11.cc
+++ b/ui/aura/test/ui_controls_factory_aurax11.cc
@@ -7,6 +7,7 @@
#include "base/bind.h"
#include "base/logging.h"
+#include "base/macros.h"
#include "ui/aura/client/screen_position_client.h"
#include "ui/aura/env.h"
#include "ui/aura/test/aura_test_utils.h"
diff --git a/ui/aura/test/ui_controls_factory_ozone.cc b/ui/aura/test/ui_controls_factory_ozone.cc
index 2f8fcb5..10cb38c 100644
--- a/ui/aura/test/ui_controls_factory_ozone.cc
+++ b/ui/aura/test/ui_controls_factory_ozone.cc
@@ -4,6 +4,7 @@
#include "base/bind.h"
#include "base/logging.h"
+#include "base/macros.h"
#include "ui/aura/client/screen_position_client.h"
#include "ui/aura/env.h"
#include "ui/aura/test/aura_test_utils.h"
diff --git a/ui/aura/test/window_event_dispatcher_test_api.h b/ui/aura/test/window_event_dispatcher_test_api.h
index a38cabf..331b763 100644
--- a/ui/aura/test/window_event_dispatcher_test_api.h
+++ b/ui/aura/test/window_event_dispatcher_test_api.h
@@ -5,7 +5,7 @@
#ifndef UI_AURA_TEST_WINDOW_EVENT_DISPATCHER_TEST_API_H_
#define UI_AURA_TEST_WINDOW_EVENT_DISPATCHER_TEST_API_H_
-#include "base/basictypes.h"
+#include "base/macros.h"
namespace aura {
diff --git a/ui/aura/test/window_test_api.h b/ui/aura/test/window_test_api.h
index 16a38cc..da131da 100644
--- a/ui/aura/test/window_test_api.h
+++ b/ui/aura/test/window_test_api.h
@@ -5,7 +5,7 @@
#ifndef UI_AURA_TEST_WINDOW_TEST_API_H_
#define UI_AURA_TEST_WINDOW_TEST_API_H_
-#include "base/basictypes.h"
+#include "base/macros.h"
namespace aura {
diff --git a/ui/aura/window.cc b/ui/aura/window.cc
index 8f27a6c..bd9f023 100644
--- a/ui/aura/window.cc
+++ b/ui/aura/window.cc
@@ -4,6 +4,8 @@
#include "ui/aura/window.h"
+#include <stddef.h>
+
#include <algorithm>
#include <utility>
@@ -11,6 +13,7 @@
#include "base/bind_helpers.h"
#include "base/callback.h"
#include "base/logging.h"
+#include "base/macros.h"
#include "base/strings/string_number_conversions.h"
#include "base/strings/string_util.h"
#include "base/strings/stringprintf.h"
@@ -597,8 +600,7 @@ void Window::SuppressPaint() {
// {Set,Get,Clear}Property are implemented in window_property.h.
void Window::SetNativeWindowProperty(const char* key, void* value) {
- SetPropertyInternal(
- key, key, NULL, reinterpret_cast<int64>(value), 0);
+ SetPropertyInternal(key, key, NULL, reinterpret_cast<int64_t>(value), 0);
}
void* Window::GetNativeWindowProperty(const char* key) const {
@@ -655,12 +657,12 @@ void Window::RemoveOrDestroyChildren() {
///////////////////////////////////////////////////////////////////////////////
// Window, private:
-int64 Window::SetPropertyInternal(const void* key,
- const char* name,
- PropertyDeallocator deallocator,
- int64 value,
- int64 default_value) {
- int64 old = GetPropertyInternal(key, default_value);
+int64_t Window::SetPropertyInternal(const void* key,
+ const char* name,
+ PropertyDeallocator deallocator,
+ int64_t value,
+ int64_t default_value) {
+ int64_t old = GetPropertyInternal(key, default_value);
if (value == default_value) {
prop_map_.erase(key);
} else {
@@ -675,8 +677,8 @@ int64 Window::SetPropertyInternal(const void* key,
return old;
}
-int64 Window::GetPropertyInternal(const void* key,
- int64 default_value) const {
+int64_t Window::GetPropertyInternal(const void* key,
+ int64_t default_value) const {
std::map<const void*, Value>::const_iterator iter = prop_map_.find(key);
if (iter == prop_map_.end())
return default_value;
diff --git a/ui/aura/window.h b/ui/aura/window.h
index 5586044..9a88d80 100644
--- a/ui/aura/window.h
+++ b/ui/aura/window.h
@@ -5,12 +5,14 @@
#ifndef UI_AURA_WINDOW_H_
#define UI_AURA_WINDOW_H_
+#include <stdint.h>
+
#include <map>
#include <string>
#include <vector>
-#include "base/basictypes.h"
#include "base/compiler_specific.h"
+#include "base/macros.h"
#include "base/memory/scoped_ptr.h"
#include "base/observer_list.h"
#include "base/strings/string16.h"
@@ -312,7 +314,7 @@ class AURA_EXPORT Window : public ui::LayerDelegate,
void* GetNativeWindowProperty(const char* key) const;
// Type of a function to delete a property that this window owns.
- typedef void (*PropertyDeallocator)(int64 value);
+ typedef void (*PropertyDeallocator)(int64_t value);
// Overridden from ui::LayerDelegate:
void OnDeviceScaleFactorChanged(float device_scale_factor) override;
@@ -337,12 +339,12 @@ class AURA_EXPORT Window : public ui::LayerDelegate,
friend class WindowTargeter;
friend class subtle::PropertyHelper;
// Called by the public {Set,Get,Clear}Property functions.
- int64 SetPropertyInternal(const void* key,
- const char* name,
- PropertyDeallocator deallocator,
- int64 value,
- int64 default_value);
- int64 GetPropertyInternal(const void* key, int64 default_value) const;
+ int64_t SetPropertyInternal(const void* key,
+ const char* name,
+ PropertyDeallocator deallocator,
+ int64_t value,
+ int64_t default_value);
+ int64_t GetPropertyInternal(const void* key, int64_t default_value) const;
// Returns true if the mouse pointer at relative-to-this-Window's-origin
// |local_point| can trigger an event for this Window.
@@ -510,7 +512,7 @@ class AURA_EXPORT Window : public ui::LayerDelegate,
// WindowProperty<>.
struct Value {
const char* name;
- int64 value;
+ int64_t value;
PropertyDeallocator deallocator;
};
diff --git a/ui/aura/window_event_dispatcher.cc b/ui/aura/window_event_dispatcher.cc
index 7874c45a..92b3b9f 100644
--- a/ui/aura/window_event_dispatcher.cc
+++ b/ui/aura/window_event_dispatcher.cc
@@ -4,10 +4,13 @@
#include "ui/aura/window_event_dispatcher.h"
+#include <stddef.h>
+
#include "base/bind.h"
#include "base/logging.h"
#include "base/message_loop/message_loop.h"
#include "base/trace_event/trace_event.h"
+#include "build/build_config.h"
#include "ui/aura/client/capture_client.h"
#include "ui/aura/client/cursor_client.h"
#include "ui/aura/client/event_client.h"
@@ -161,7 +164,7 @@ DispatchDetails WindowEventDispatcher::DispatchMouseExitAtPoint(
return DispatchMouseEnterOrExit(window, event, ui::ET_MOUSE_EXITED);
}
-void WindowEventDispatcher::ProcessedTouchEvent(uint32 unique_event_id,
+void WindowEventDispatcher::ProcessedTouchEvent(uint32_t unique_event_id,
Window* window,
ui::EventResult result) {
scoped_ptr<ui::GestureRecognizer::Gestures> gestures(
diff --git a/ui/aura/window_event_dispatcher.h b/ui/aura/window_event_dispatcher.h
index 0d3dca4..ccd5b26 100644
--- a/ui/aura/window_event_dispatcher.h
+++ b/ui/aura/window_event_dispatcher.h
@@ -5,10 +5,12 @@
#ifndef UI_AURA_WINDOW_EVENT_DISPATCHER_H_
#define UI_AURA_WINDOW_EVENT_DISPATCHER_H_
+#include <stdint.h>
+
#include <vector>
-#include "base/basictypes.h"
#include "base/gtest_prod_util.h"
+#include "base/macros.h"
#include "base/memory/ref_counted.h"
#include "base/memory/scoped_ptr.h"
#include "base/memory/weak_ptr.h"
@@ -94,7 +96,7 @@ class AURA_EXPORT WindowEventDispatcher : public ui::EventProcessor,
// event processing, so that gesture events can be properly created and
// dispatched. |event|'s location should be in the dispatcher's coordinate
// space, in DIPs.
- virtual void ProcessedTouchEvent(uint32 unique_event_id,
+ virtual void ProcessedTouchEvent(uint32_t unique_event_id,
Window* window,
ui::EventResult result);
@@ -246,7 +248,7 @@ class AURA_EXPORT WindowEventDispatcher : public ui::EventProcessor,
WindowTreeHost* host_;
// Touch ids that are currently down.
- uint32 touch_ids_down_;
+ uint32_t touch_ids_down_;
Window* mouse_pressed_handler_;
Window* mouse_moved_handler_;
diff --git a/ui/aura/window_event_dispatcher_unittest.cc b/ui/aura/window_event_dispatcher_unittest.cc
index 21a3170..3f412b2 100644
--- a/ui/aura/window_event_dispatcher_unittest.cc
+++ b/ui/aura/window_event_dispatcher_unittest.cc
@@ -4,12 +4,16 @@
#include "ui/aura/window_event_dispatcher.h"
+#include <stddef.h>
+
#include <utility>
#include <vector>
#include "base/bind.h"
+#include "base/macros.h"
#include "base/run_loop.h"
#include "base/thread_task_runner_handle.h"
+#include "build/build_config.h"
#include "testing/gtest/include/gtest/gtest.h"
#include "ui/aura/client/capture_client.h"
#include "ui/aura/client/event_client.h"
diff --git a/ui/aura/window_observer.h b/ui/aura/window_observer.h
index f4e7237..f3123c0 100644
--- a/ui/aura/window_observer.h
+++ b/ui/aura/window_observer.h
@@ -5,7 +5,7 @@
#ifndef UI_AURA_WINDOW_OBSERVER_H_
#define UI_AURA_WINDOW_OBSERVER_H_
-#include "base/basictypes.h"
+#include "base/macros.h"
#include "base/strings/string16.h"
#include "ui/aura/aura_export.h"
diff --git a/ui/aura/window_targeter_unittest.cc b/ui/aura/window_targeter_unittest.cc
index de362e9..01893a8 100644
--- a/ui/aura/window_targeter_unittest.cc
+++ b/ui/aura/window_targeter_unittest.cc
@@ -6,6 +6,7 @@
#include <utility>
+#include "base/macros.h"
#include "ui/aura/scoped_window_targeter.h"
#include "ui/aura/test/aura_test_base.h"
#include "ui/aura/test/test_window_delegate.h"
diff --git a/ui/aura/window_tracker.h b/ui/aura/window_tracker.h
index 005dde3..65fcf68 100644
--- a/ui/aura/window_tracker.h
+++ b/ui/aura/window_tracker.h
@@ -7,8 +7,8 @@
#include <vector>
-#include "base/basictypes.h"
#include "base/compiler_specific.h"
+#include "base/macros.h"
#include "ui/aura/aura_export.h"
#include "ui/aura/window_observer.h"
diff --git a/ui/aura/window_tree_host.h b/ui/aura/window_tree_host.h
index 31d6904..6821de4 100644
--- a/ui/aura/window_tree_host.h
+++ b/ui/aura/window_tree_host.h
@@ -8,6 +8,7 @@
#include <vector>
#include "base/event_types.h"
+#include "base/macros.h"
#include "base/message_loop/message_loop.h"
#include "ui/aura/aura_export.h"
#include "ui/base/cursor/cursor.h"
diff --git a/ui/aura/window_tree_host_mac.h b/ui/aura/window_tree_host_mac.h
index 5c7ca98..eefb7e1 100644
--- a/ui/aura/window_tree_host_mac.h
+++ b/ui/aura/window_tree_host_mac.h
@@ -8,6 +8,7 @@
#include <vector>
#include "base/mac/scoped_nsobject.h"
+#include "base/macros.h"
#include "ui/aura/aura_export.h"
#include "ui/aura/window_tree_host.h"
#include "ui/gfx/geometry/insets.h"
diff --git a/ui/aura/window_tree_host_platform.cc b/ui/aura/window_tree_host_platform.cc
index a696eea..1e4baf6 100644
--- a/ui/aura/window_tree_host_platform.cc
+++ b/ui/aura/window_tree_host_platform.cc
@@ -7,6 +7,7 @@
#include <utility>
#include "base/trace_event/trace_event.h"
+#include "build/build_config.h"
#include "ui/aura/window_event_dispatcher.h"
#include "ui/compositor/compositor.h"
#include "ui/events/event.h"
diff --git a/ui/aura/window_tree_host_platform.h b/ui/aura/window_tree_host_platform.h
index b885e73..111a1cd 100644
--- a/ui/aura/window_tree_host_platform.h
+++ b/ui/aura/window_tree_host_platform.h
@@ -6,6 +6,7 @@
#define UI_AURA_WINDOW_TREE_HOST_PLATFORM_H_
#include "base/compiler_specific.h"
+#include "base/macros.h"
#include "base/memory/scoped_ptr.h"
#include "ui/aura/aura_export.h"
#include "ui/aura/window_tree_host.h"
diff --git a/ui/aura/window_tree_host_x11.cc b/ui/aura/window_tree_host_x11.cc
index e1abcac..ebcb154 100644
--- a/ui/aura/window_tree_host_x11.cc
+++ b/ui/aura/window_tree_host_x11.cc
@@ -16,8 +16,8 @@
#include <limits>
#include <string>
-#include "base/basictypes.h"
#include "base/command_line.h"
+#include "base/macros.h"
#include "base/stl_util.h"
#include "base/strings/string_number_conversions.h"
#include "base/strings/string_split.h"
@@ -25,6 +25,7 @@
#include "base/strings/stringprintf.h"
#include "base/sys_info.h"
#include "base/trace_event/trace_event.h"
+#include "build/build_config.h"
#include "ui/aura/client/cursor_client.h"
#include "ui/aura/env.h"
#include "ui/aura/window.h"
diff --git a/ui/aura/window_tree_host_x11.h b/ui/aura/window_tree_host_x11.h
index bc994a7..906f605 100644
--- a/ui/aura/window_tree_host_x11.h
+++ b/ui/aura/window_tree_host_x11.h
@@ -5,6 +5,9 @@
#ifndef UI_AURA_WINDOW_TREE_HOST_X11_H_
#define UI_AURA_WINDOW_TREE_HOST_X11_H_
+#include <stdint.h>
+
+#include "base/macros.h"
#include "base/memory/scoped_ptr.h"
#include "ui/aura/aura_export.h"
#include "ui/aura/window_tree_host.h"
diff --git a/ui/aura/window_unittest.cc b/ui/aura/window_unittest.cc
index 5fc4816..8df4db5 100644
--- a/ui/aura/window_unittest.cc
+++ b/ui/aura/window_unittest.cc
@@ -8,11 +8,12 @@
#include <utility>
#include <vector>
-#include "base/basictypes.h"
#include "base/compiler_specific.h"
+#include "base/macros.h"
#include "base/strings/string_number_conversions.h"
#include "base/strings/string_util.h"
#include "base/strings/stringprintf.h"
+#include "build/build_config.h"
#include "testing/gtest/include/gtest/gtest.h"
#include "ui/aura/client/capture_client.h"
#include "ui/aura/client/focus_change_observer.h"
diff --git a/ui/aura/window_property.h b/ui/aura/window_property.h
index 3cc981c..1f8a635 100644
--- a/ui/aura/window_property.h
+++ b/ui/aura/window_property.h
@@ -5,7 +5,8 @@
#ifndef UI_AURA_WINDOW_PROPERTY_H_
#define UI_AURA_WINDOW_PROPERTY_H_
-#include "base/basictypes.h"
+#include <stdint.h>
+
#include "ui/aura/aura_export.h"
#include "ui/aura/window.h"
@@ -45,27 +46,27 @@
namespace aura {
namespace {
// No single new-style cast works for every conversion to/from int64, so we
// need this helper class. A third specialization is needed for bool because
// MSVC warning C4800 (forcing value to bool) is not suppressed by an explicit
// cast (!).
template<typename T>
class WindowPropertyCaster {
public:
- static int64 ToInt64(T x) { return static_cast<int64>(x); }
- static T FromInt64(int64 x) { return static_cast<T>(x); }
+ static int64_t ToInt64(T x) { return static_cast<int64_t>(x); }
+ static T FromInt64(int64_t x) { return static_cast<T>(x); }
};
template<typename T>
class WindowPropertyCaster<T*> {
public:
- static int64 ToInt64(T* x) { return reinterpret_cast<int64>(x); }
- static T* FromInt64(int64 x) { return reinterpret_cast<T*>(x); }
+ static int64_t ToInt64(T* x) { return reinterpret_cast<int64_t>(x); }
+ static T* FromInt64(int64_t x) { return reinterpret_cast<T*>(x); }
};
template<>
class WindowPropertyCaster<bool> {
public:
- static int64 ToInt64(bool x) { return static_cast<int64>(x); }
- static bool FromInt64(int64 x) { return x != 0; }
+ static int64_t ToInt64(bool x) { return static_cast<int64_t>(x); }
+ static bool FromInt64(int64_t x) { return x != 0; }
};
} // namespace
@@ -83,9 +84,8 @@ class AURA_EXPORT PropertyHelper {
public:
template<typename T>
static void Set(Window* window, const WindowProperty<T>* property, T value) {
- int64 old = window->SetPropertyInternal(
- property,
- property->name,
+ int64_t old = window->SetPropertyInternal(
+ property, property->name,
value == property->default_value ? nullptr : property->deallocator,
WindowPropertyCaster<T>::ToInt64(value),
WindowPropertyCaster<T>::ToInt64(property->default_value));
@@ -128,31 +128,29 @@ class AURA_EXPORT PropertyHelper {
#define DECLARE_WINDOW_PROPERTY_TYPE(T) \
DECLARE_EXPORTED_WINDOW_PROPERTY_TYPE(, T)
-#define DEFINE_WINDOW_PROPERTY_KEY(TYPE, NAME, DEFAULT) \
- static_assert(sizeof(TYPE) <= sizeof(int64), "property type too large"); \
- namespace { \
- const aura::WindowProperty<TYPE> NAME ## _Value = \
- {DEFAULT, #NAME, nullptr}; \
- } \
- const aura::WindowProperty<TYPE>* const NAME = & NAME ## _Value;
-
-#define DEFINE_LOCAL_WINDOW_PROPERTY_KEY(TYPE, NAME, DEFAULT) \
- static_assert(sizeof(TYPE) <= sizeof(int64), "property type too large"); \
- namespace { \
- const aura::WindowProperty<TYPE> NAME ## _Value = \
- {DEFAULT, #NAME, nullptr}; \
- const aura::WindowProperty<TYPE>* const NAME = & NAME ## _Value; \
+#define DEFINE_WINDOW_PROPERTY_KEY(TYPE, NAME, DEFAULT) \
+ static_assert(sizeof(TYPE) <= sizeof(int64_t), "property type too large"); \
+ namespace { \
+ const aura::WindowProperty<TYPE> NAME##_Value = {DEFAULT, #NAME, nullptr}; \
+ } \
+ const aura::WindowProperty<TYPE>* const NAME = &NAME##_Value;
+
+#define DEFINE_LOCAL_WINDOW_PROPERTY_KEY(TYPE, NAME, DEFAULT) \
+ static_assert(sizeof(TYPE) <= sizeof(int64_t), "property type too large"); \
+ namespace { \
+ const aura::WindowProperty<TYPE> NAME##_Value = {DEFAULT, #NAME, nullptr}; \
+ const aura::WindowProperty<TYPE>* const NAME = &NAME##_Value; \
}
-#define DEFINE_OWNED_WINDOW_PROPERTY_KEY(TYPE, NAME, DEFAULT) \
- namespace { \
- void Deallocator ## NAME (int64 p) { \
- enum { type_must_be_complete = sizeof(TYPE) }; \
- delete aura::WindowPropertyCaster<TYPE*>::FromInt64(p); \
- } \
- const aura::WindowProperty<TYPE*> NAME ## _Value = \
- {DEFAULT,#NAME,&Deallocator ## NAME}; \
- } \
- const aura::WindowProperty<TYPE*>* const NAME = & NAME ## _Value;
+#define DEFINE_OWNED_WINDOW_PROPERTY_KEY(TYPE, NAME, DEFAULT) \
+ namespace { \
+ void Deallocator##NAME(int64_t p) { \
+ enum { type_must_be_complete = sizeof(TYPE) }; \
+ delete aura::WindowPropertyCaster<TYPE*>::FromInt64(p); \
+ } \
+ const aura::WindowProperty<TYPE*> NAME##_Value = {DEFAULT, #NAME, \
+ &Deallocator##NAME}; \
+ } \
+ const aura::WindowProperty<TYPE*>* const NAME = &NAME##_Value;
#endif // UI_AURA_WINDOW_PROPERTY_H_
@@ -45,27 +46,27 @@
namespace aura {
namespace {
-// No single new-style cast works for every conversion to/from int64, so we
+// No single new-style cast works for every conversion to/from int64_t, so we
// need this helper class. A third specialization is needed for bool because
// MSVC warning C4800 (forcing value to bool) is not suppressed by an explicit